@@ -21,9 +21,7 @@ class Storage;
 class AKREGATORINTERFACES_EXPORT StorageFactory
 {
 public:
-    virtual ~StorageFactory()
-    {
-    }
+    virtual ~StorageFactory() = default;
 
     /** identifier of the storage type, like "metakit", "postgres" etc. For use in
         configuration files. Must not contain spaces or special characters.
