@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -37,9 +37,7 @@ private Q_SLOTS:
 
 private:
     struct StatusInfo {
-        StatusInfo()
-        {
-        }
+        StatusInfo() = default;
 
         StatusInfo(const QString &text, const QIcon &icon)
             : mText(text)
